;;; 
;;; mymac-ed.el
;;;
;;; By Ross Ridge
;;; Public Domain
;;;
;;; A major mode for editing mymac input.
;;;

(require 'mymac)

(defconst mymac-ed-ident "@(#) mymac mymac-ed.el 2.2 95/04/09 02:55:55")

(defvar mymac-edit-mode-syntax-table nil)

(if mymac-edit-mode-syntax-table
    nil
  (setq mymac-edit-mode-syntax-table
	(copy-syntax-table emacs-lisp-mode-syntax-table))
  (modify-syntax-entry ?$ "'" mymac-edit-mode-syntax-table)
  (modify-syntax-entry ?{ "(}" mymac-edit-mode-syntax-table)
  (modify-syntax-entry ?} "){" mymac-edit-mode-syntax-table))

(defvar mymac-edit-mode-map nil)

(if mymac-edit-mode-map
    nil
  (setq mymac-edit-mode-map (make-sparse-keymap))
  (if (boundp 'shared-lisp-mode-map)
      (setq mymac-edit-mode-map
	    (nconc mymac-edit-mode-map shared-lisp-mode-map)))
  (autoload 'mymac-expand-buffer "mymac" "" t nil)
  (define-key mymac-edit-mode-map "\C-c\C-e" 'mymac-expand-buffer)
  (define-key mymac-edit-mode-map "\C-c`" 'mymac-toggle-syntax)
  (define-key mymac-edit-mode-map "\e\t" 'lisp-complete-symbol)  

  (if (fboundp 'lisp-mode-commands)
      (lisp-mode-commands mymac-edit-mode-map)))

(defun mymac-edit-mode () 
  "Major mode for editting mymac input.

Special Commands:
\\{mymac-edit-mode-map}"
  (interactive)
  (kill-all-local-variables)
  (use-local-map mymac-edit-mode-map)
  (set-syntax-table mymac-syntax-table)
  (setq major-mode 'mymac-edit-mode)
  (setq mode-name "Mymac-Edit")
  (lisp-mode-variables nil))

(defun mymac-toggle-syntax ()
  "Toggle the current syntax table between mymac and lisp tables. 
The mymac table is useful when editting ordinary mymac macros and the
lisp table is useful when editting the lisp code in a bind-lisp-expr
macro."
  (interactive)
  (require 'mymac)
  (if (eq (syntax-table) mymac-edit-mode-syntax-table)
      (progn (set-syntax-table mymac-syntax-table)
	     (setq mode-name "Mymac-Edit"))
    (if (eq (syntax-table) mymac-syntax-table)
	(progn (set-syntax-table mymac-edit-mode-syntax-table)
	       (setq mode-name "Mymac+Edit"))))
  (force-mode-line-update))

(provide 'mymac-ed)


